<?php
/**
 * DATA
 *
 * @package     Demon_Image_Annotation
 * @author      demonisblack
 * @license     GPL-2.0+
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

require_once 'functions.php';

global $wpdb;
if ( ( get_option( 'demon_image_annotation_comments' ) === '0' ) ) {
	// Moderate comments.
	$result = $wpdb->get_results( $wpdb->prepare( 'SELECT %1s.note_ID, %1s.note_approved, %1s.comment_approved FROM %1s, %1s WHERE %1s.note_approved != %1s.comment_approved AND %1s.note_comment_ID = %1s.comment_ID', DIA_TABLE_NOTES, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS ) );
	foreach ( $result as $r ) {
		$wpdb->update(
			DIA_TABLE_NOTES,
			array(
				'note_approved' => $r->comment_approved,
			),
			array(
				'note_ID' => $r->note_ID,
			)
		);
	}

	// Content.
	$result = $wpdb->get_results( $wpdb->prepare( 'SELECT %1s.note_ID, %1s.note_text, %1s.comment_content FROM %1s, %1s WHERE %1s.note_text != %1s.comment_content	AND %1s.note_comment_ID = %1s.comment_ID', DIA_TABLE_NOTES, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS ) );
	foreach ( $result as $r ) {
		$wpdb->update(
			DIA_TABLE_NOTES,
			array(
				'note_text' => addslashes( $r->comment_content ),
			),
			array(
				'note_ID' => $r->note_ID,
			)
		);
	}

	// Author.
	$result = $wpdb->get_results( $wpdb->prepare( 'SELECT %1s.note_ID, %1s.note_author, %1s.comment_author	FROM %1s, %1s	WHERE %1s.note_author != %1s.comment_author AND %1s.note_comment_ID = %1s.comment_ID', DIA_TABLE_NOTES, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS ) );
	foreach ( $result as $r ) {
		$wpdb->update(
			DIA_TABLE_NOTES,
			array(
				'note_author' => $r->comment_author,
			),
			array(
				'note_ID' => $r->note_ID,
			)
		);
	}

	// Email.
	$result = $wpdb->get_results( $wpdb->prepare( 'SELECT %1s.note_ID, %1s.note_email, %1s.comment_author_email FROM %1s, %1s WHERE %1s.note_email != %1s.comment_author_email AND %1s.note_comment_ID = %1s.comment_ID', DIA_TABLE_NOTES, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS, DIA_TABLE_NOTES, DIA_TABLE_COMMENTS ) );
	foreach ( $result as $r ) {
		$wpdb->update(
			DIA_TABLE_NOTES,
			array(
				'note_email' => $r->comment_author_email,
			),
			array(
				'note_ID' => $r->note_ID,
			)
		);
	}
}

$data_action = ( isset( $_REQUEST['action'] ) ? sanitize_text_field( wp_unslash( $_REQUEST['action'] ) ) : '' );
if ( is_admin() && '' !== $data_action ) {
	if ( isset( $_REQUEST['note'] ) ) {
		$noteid = ( is_array( $_REQUEST['note'] ) ) ? dia_sanitize_text_or_array_field( wp_unslash( $_REQUEST['note'] ) ) : array( dia_sanitize_text_or_array_field( wp_unslash( $_REQUEST['note'] ) ) );
	}

	// Define our data source.
	if ( 'delete' === $data_action ) {
		foreach ( $noteid as $this_id ) {
			$this_id = absint( sanitize_text_field( $this_id ) );
			if ( ( get_option( 'demon_image_annotation_comments' ) === '0' ) ) {
				// Find comment id and comment text.
				$result = $wpdb->get_results( $wpdb->prepare( 'SELECT * from %1s WHERE note_ID = %s', DIA_TABLE_NOTES, sanitize_text_field( $this_id ) ) );
				foreach ( $result as $r ) {
					$comment_id = $r->note_comment_ID;
					$content    = $r->note_text;
					// Delete comment.
					$wpdb->delete(
						DIA_TABLE_COMMENTS,
						array(
							'comment_ID'      => $comment_id,
							'comment_content' => $content,
						)
					);
				}
			}
			// Delete note.
			$wpdb->delete( DIA_TABLE_NOTES, array( 'note_ID' => $this_id ) );
			$wpdb->delete( 'wp_comments', array( 'comment_ID' => $comment_id ) );
		}
	} elseif ( 'approve' === $data_action ) {
		foreach ( $noteid as $this_id ) {
			$this_id = absint( sanitize_text_field( $this_id ) );
			if ( ( get_option( 'demon_image_annotation_comments' ) === '0' ) ) {
				// Find comment id and comment text.
				$result = $wpdb->get_results( $wpdb->prepare( 'SELECT * from %1s WHERE note_ID = %s', DIA_TABLE_NOTES, sanitize_text_field( $this_id ) ) );
				foreach ( $result as $r ) {
					$comment_id = $r->note_comment_ID;
					$content    = $r->note_text;
					// Approve comment.
					$wpdb->update(
						DIA_TABLE_COMMENTS,
						array(
							'comment_approved' => '1',
						),
						array(
							'comment_ID'      => $comment_id,
							'comment_content' => $content,
						)
					);
				}
			}
			// Approve note.
			$wpdb->update(
				DIA_TABLE_NOTES,
				array(
					'note_approved' => '1',
				),
				array(
					'note_ID' => $this_id,
				)
			);
		}
	} elseif ( 'restore' === $data_action ) {
		foreach ( $noteid as $this_id ) {
			$this_id = absint( sanitize_text_field( $this_id ) );
			if ( ( get_option( 'demon_image_annotation_comments' ) === '0' ) ) {
				// Find comment id and comment text.
				$result = $wpdb->get_results( $wpdb->prepare( 'SELECT * from %1s WHERE note_ID = %s', DIA_TABLE_NOTES, sanitize_text_field( $this_id ) ) );
				foreach ( $result as $r ) {
					$comment_id = $r->note_comment_ID;
					$content    = $r->note_text;
					// Approve comment.
					$wpdb->update(
						DIA_TABLE_COMMENTS,
						array(
							'comment_approved' => '1',
						),
						array(
							'comment_ID'      => $comment_id,
							'comment_content' => $content,
						)
					);
				}
			}
			// Approve note.
			$wpdb->update(
				DIA_TABLE_NOTES,
				array(
					'note_approved' => '1',
				),
				array(
					'note_ID' => $this_id,
				)
			);
		}
	} elseif ( 'unapprove' === $data_action ) {
		foreach ( $noteid as $this_id ) {
			$this_id = absint( $this_id );
			if ( ( get_option( 'demon_image_annotation_comments' ) === '0' ) ) {
				// Find comment id and comment text.
				$result = $wpdb->get_results( $wpdb->prepare( 'SELECT * from %1s WHERE note_ID = %s', DIA_TABLE_NOTES, sanitize_text_field( $this_id ) ) );
				foreach ( $result as $r ) {
					$comment_id = $r->note_comment_ID;
					$content    = $r->note_text;
					// Approve comment.
					$wpdb->update(
						DIA_TABLE_COMMENTS,
						array(
							'comment_approved' => '0',
						),
						array(
							'comment_ID'      => $comment_id,
							'comment_content' => $content,
						)
					);
				}
			}
			// Unapprove note.
			$wpdb->update(
				DIA_TABLE_NOTES,
				array(
					'note_approved' => '0',
				),
				array(
					'note_ID' => $this_id,
				)
			);
		}
	}
}

